==> Acme-CPANLists-Import-RSAVAGE-0.01.tar.gz: Acme-CPANLists-Import-RSAVAGE-0.01/lib/Acme/CPANLists/Import/RSAVAGE.pm <==
package Acme::CPANLists::Import::SHARYANTO;

our $DATE = '2016-02-21'; # DATE
our $VERSION = '0.01'; # VERSION

1;
# ABSTRACT: CPANLists imported from Steven Haryanto's blog posts

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANLists::Import::SHARYANTO - CPANLists imported from Steven Haryanto's blog posts

=head1 VERSION

This document describes version 0.01 of Acme::CPANLists::Import::SHARYANTO (from Perl distribution Acme-CPANLists-Import-RSAVAGE), released on 2016-02-21.

=head1 DESCRIPTION

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANLists-Import-RSAVAGE>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANLists-Import-RSAVAGE>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANLists-Import-RSAVAGE>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANLists> - about the Acme::CPANLists namespace

L<acme-cpanlists> - CLI tool to let you browse/view the lists

L<App::lcpan> and L<lcpan>, particularly the B<related-mods> subcommand.

Other C<Acme::CPANLists::Import::*> distributions.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Acme-CPANLists-Import-RSAVAGE-0.02.tar.gz: Acme-CPANLists-Import-RSAVAGE-0.02/lib/Acme/CPANLists/Import/RSAVAGE.pm <==
package Acme::CPANLists::Import::RSAVAGE;

our $DATE = '2016-02-21'; # DATE
our $VERSION = '0.02'; # VERSION

1;
# ABSTRACT: CPANLists imported from Ron Savage's blog posts

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANLists::Import::RSAVAGE - CPANLists imported from Ron Savage's blog posts

=head1 VERSION

This document describes version 0.02 of Acme::CPANLists::Import::RSAVAGE (from Perl distribution Acme-CPANLists-Import-RSAVAGE), released on 2016-02-21.

=head1 DESCRIPTION

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANLists-Import-RSAVAGE>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANLists-Import-RSAVAGE>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANLists-Import-RSAVAGE>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANLists> - about the Acme::CPANLists namespace

L<acme-cpanlists> - CLI tool to let you browse/view the lists

L<App::lcpan> and L<lcpan>, particularly the B<related-mods> subcommand.

Other C<Acme::CPANLists::Import::*> distributions.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
